import React, {FC, useState} from "react"
import { StyleSheet} from "react-native"
import { DemoTabScreenProps } from "../../navigators/DemoNavigator"
import {
    Viro3DObject,
    ViroAmbientLight,
    ViroARScene,
    ViroARSceneNavigator, ViroNode
} from "@viro-community/react-viro";
import {Viro3DPoint} from "@viro-community/react-viro/dist/components/Types/ViroUtils";
import {ViroARObjectPlacer} from "./components/ViroARObjectPlacer";


const ARStyles = StyleSheet.create({
    f1: {flex: 1},
    helloWorldTextStyle: {
        color: '#ffffff',
        fontFamily: 'Arial',
        fontSize: 30,
        textAlign: 'center',
        textAlignVertical: 'center',
    },
});

const HelloWorldSceneAR = () => {
    const [canvasPosition, setCanvasPosition] = useState(null as Viro3DPoint);
    const [anchor, setAnchor] = useState(null as any);

    function onInitialized(state, reason) {
        console.log('guncelleme', state, reason);
    }

    function onPlaneSelected(anchor: any){
        console.log('onPlaneSelected', anchor);
        setAnchor(anchor);
    }

    function onPlaceFrame(pos: Viro3DPoint){
        console.log('onPlaceFrame', pos);
        setCanvasPosition(pos);
    }

    return (
        <ViroARScene onTrackingUpdated={onInitialized}
                     anchorDetectionTypes="PlanesVertical">
            <ViroAmbientLight color="#FF0000" />
            <ViroARObjectPlacer
                minHeight={.5}
                minWidth={.5}
                alignment="Vertical"
                onPlaneSelected={onPlaneSelected}
                onObjectPlaced={onPlaceFrame}>
                {canvasPosition && <ViroNode position={canvasPosition}>
                    <Viro3DObject
                        scale={[0.5, 0.5, 0.5]}
                        rotation={[0, 0, 90]}
                        position={[0.5, 0, -0.5]}
                        dragType="FixedToWorld"
                        onDrag={()=> {}}
                        source={require('../../../assets/painting/painting.obj')}
                        resources={[require('../../../assets/painting/painting.mtl')]}
                        type="OBJ"/>
                </ViroNode>}
            </ViroARObjectPlacer>
        </ViroARScene>
    );
};

export const DemoARScreen: FC<DemoTabScreenProps<"DemoAR">> =
    function DemoARScreen(_props) {
        return (
            <ViroARSceneNavigator
                autofocus={true}
                initialScene={{
                    scene: HelloWorldSceneAR,
                }}
                style={ARStyles.f1}
            />
        )
    }

// @demo remove-file
